antares.apps.core.manager package
=================================

Submodules
----------

antares.apps.core.manager.period\_manager module
------------------------------------------------

.. automodule:: antares.apps.core.manager.period_manager
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.core.manager
   :members:
   :undoc-members:
   :show-inheritance:
